==> edelweiss-0.1.0.tar.gz: edelweiss-0.1.0/README.md <==
# edelweiss

[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
[![Open Source](https://badgen.net/badge/Open%20Source%20%3F/Yes%21/blue?icon=github)](https://github.com/Naereen/badges/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/edelweiss.svg)](https://pypi.python.org/pypi/edelweiss/)
[![PyPI version](https://badge.fury.io/py/edelweiss.svg)](https://badge.fury.io/py/edelweiss)
[![image](https://img.shields.io/badge/arXiv-0000.00000-B31B1B.svg?logo=arxiv&style=flat)](https://arxiv.org/abs/?)

[![pipeline](https://gitlab.com/cosmology-ethz/edelweiss/badges/main/pipeline.svg)](https://gitlab.com/cosmology-ethz/edelweiss/-/pipelines)
[![coverage](https://gitlab.com/cosmology-ethz/edelweiss/badges/main/coverage.svg)](https://gitlab.com/cosmology-ethz/edelweiss)
<a href="./htmlcov/index.html">
  <img src="https://img.shields.io/badge/coverage_report-green"
    alt="coverage report"/>
</a>
![GitLab Issues](https://img.shields.io/gitlab/issues/open/cosmology-ethz%2Fedelweiss)

General package to build emulators with various architectures. If you
use it, please cite the following paper:
[Fischbacher+ (2024), arXiv-?](https://arxiv.org/abs/?)

[Source](https://gitlab.com/cosmology-ethz/edelweiss/)

[Documentation](http://cosmo-docs.phys.ethz.ch/edelweiss)

## Installation and usage
Instructions on how to install and use the package can be found in the
[documentation](http://cosmo-docs.phys.ethz.ch/edelweiss).

## Why edelweiss?
The name comes from its first application in arxiv?? and is an acronym
for **E**mulator for **D**etection probability and s**E**xtractor
**L**abel prediction **W**ith **E**xtendable **I**mplementation of
**S**tatistical **S**oftware.

## Credits
This package was created by Silvan Fischbacher.
The package is maintained by Silvan Fischbacher: silvanf@phys.ethz.ch.

## Contributions
Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

==> edelweiss-0.1.1a1.tar.gz: edelweiss-0.1.1a1/README.md <==
# edelweiss

[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/edelweiss.svg)](https://pypi.python.org/pypi/edelweiss/)
[![PyPI version](https://badge.fury.io/py/edelweiss.svg)](https://badge.fury.io/py/edelweiss)
[![pipeline](https://gitlab.com/cosmology-ethz/edelweiss/badges/main/pipeline.svg)](https://gitlab.com/cosmology-ethz/edelweiss/-/pipelines)
[![issues](https://img.shields.io/gitlab/issues/open/cosmology-ethz%2Fedelweiss)](https://gitlab.com/cosmology-ethz/edelweiss/-/issues)
[![coverage](https://gitlab.com/cosmology-ethz/edelweiss/badges/main/coverage.svg)](https://gitlab.com/cosmology-ethz/edelweiss)
<a href="https://cosmo-docs.phys.ethz.ch/edelweiss/htmlcov/index.html">
  <img src="https://img.shields.io/badge/coverage_report-green"
    alt="coverage report"/>
</a>

[![image](https://img.shields.io/badge/arXiv-0000.00000-B31B1B.svg?logo=arxiv&style=flat)](https://arxiv.org/abs/?)
[![Docs](https://badgen.net/badge/icon/Documentation?icon=https://cdn.jsdelivr.net/npm/simple-icons@v13/icons/gitbook.svg&label)](https://cosmo-docs.phys.ethz.ch/edelweiss/)
[![Source Code](https://badgen.net/badge/icon/Source%20Code?icon=github&label)](https://gitlab.com/cosmology-ethz/edelweiss/)

General package to build emulators with various architectures. If you
use it, please cite the following paper:
[Fischbacher+ (2024), arXiv-?](https://arxiv.org/abs/?)

## Installation and usage

The package can be installed via pip:
```bash
pip install edelweiss
```
For further information, we refer to the [documentation](http://cosmo-docs.phys.ethz.ch/edelweiss).

## Why edelweiss?
The name comes from its first application in arxiv?? and is an acronym
for **E**mulator for **D**etection probability and s**E**xtractor
**L**abel prediction **W**ith **E**xtendable **I**mplementation of
**S**tatistical **S**oftware.

## Credits
This package was created by Silvan Fischbacher.
The package is maintained by Silvan Fischbacher: silvanf@phys.ethz.ch.

## Contributions
Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.
